@@ -1,7 +1,7 @@
 package Acme::PERLANCAR::Test::MetaCPAN::HTML::Inline1;
 
 our $DATE = '2019-01-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Test inline HTML
@@ -18,9 +18,9 @@ Acme::PERLANCAR::Test::MetaCPAN::HTML::Inline1 - Test inline HTML
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::PERLANCAR::Test::MetaCPAN::HTML::Inline1 (from Perl distribution Acme-PERLANCAR-Test-MetaCPAN-HTML), released on 2019-01-22.
+This document describes version 0.003 of Acme::PERLANCAR::Test::MetaCPAN::HTML::Inline1 (from Perl distribution Acme-PERLANCAR-Test-MetaCPAN-HTML), released on 2019-01-22.
 
-=for html <!-- begin comment --><table><tr><td>1</td><td>2</td></tr></table><!-- end comment -->
+=for html <!-- begin comment --><table border><tr><td>1</td><td>2</td></tr></table><!-- end comment -->
 
 =for html <!-- begin comment --><script src="https://code.jquery.com/jquery-3.3.1.slim.min.js" /></script><!-- end comment -->
 
@@ -30,7 +30,26 @@ This document describes version 0.002 of Acme::PERLANCAR::Test::MetaCPAN::HTML::
 
 =for html <!-- begin comment --><style> </style><!-- end comment -->
 
-=for html <div id=#one> </div>
+=for html <div id=#one> inside div </div>
+
+=for html <div class=one> inside div2 </div>
+
+=for html <pre class="line-numbers">foo</pre>
+
+=for html <pre class="line-numbers">line 1
+line 2
+line 3
+</pre>
+
+=head1 NOTES
+
+Tables allowed.
+
+HTML comments stripped.
+
+<script>, <style> stripped.
+
+<div> allowed but attributes stripped.
 
 =head1 HOMEPAGE
 
